@@ -6,7 +6,7 @@ failures=0
 FAKE_PROC=false
 cleanup () {
 	if $FAKE_PROC && [ -e "$tmpdir/proc/register" ]; then
-		umount "$tmpdir/proc"
+		fusermount -u "$tmpdir/proc"
 	fi
 	rm -rf "$tmpdir"
 }
@@ -26,6 +26,7 @@ fake_proc () {
 	else
 		if ! "$srcdir/binfmt_misc.py" "$tmpdir/proc" 2>/dev/null; then
 			echo "SKIP: fuse unavailable"
+			cleanup
 			exit 77
 		fi
 	fi
